"""templer.django_project_app"""
import os

from templer.core.base import BaseTemplate


class DjangoProjectApp(BaseTemplate):
    _template_dir = 'templates/django_project_app'
    summary = "A basic Django project application skeleton"
    category = 'Django'
    vars = []
    use_cheetah = True
    help = """
This creates a basic skeleton for a Django application within a project.
"""

    def pre(self, command, output_dir, vars):
        vars['project'] = os.path.split(os.getcwd())[-1]



"""Setup script for templer.django-project-app"""
from setuptools import setup
from setuptools import find_packages

version = '0.1'

setup(name='templer.django-project-app',
      version=version,
      description="Templer system extensions for Django applications within projects",
      long_description=open('README.rst').read(),
      classifiers=[
        "Environment :: Console",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Code Generators",
        ],
      keywords='templer, django, application',
      author='Fantomas42',
      author_email='fantomas42@gmail.com',
      url='https://github.com/collective/templer.django-project-app',
      license='BSD',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['templer'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'templer.core',
      ],
      entry_points="""
      [paste.paster_create_template]
      django_project_app = templer.django_project_app:DjangoProjectApp
      """,
      )
